is.ancestor: Check if clone a is ancestor of clone b in the clonal...

Description Usage Arguments

Description

Check if clone a is ancestor of clone b in the clonal evolution tree

Usage

1
x = is.ancestor(v, a, b)

Arguments

v:

clonal structure data frame

a:

label of the cluster/clone a

b:

label of the cluster/clone a


hadaxu/clonevol-mirror documentation built on May 17, 2019, 9:42 a.m.